// Generated by CoffeeScript 1.12.2
(function() {
  module.exports = function(length, fn) {
    if (!(typeof fn === "function" || fn instanceof Function)) {
      throw new Error("second argument must be a function, but it was " + (typeof fn));
    }
    if (!(length >= 0)) {
      throw new Error("Timeout length must be positive, but it was `" + length + "`.");
    }
    if (!(length > 0 || typeof length === "number" || length instanceof Number)) {
      throw new Error("If timeout length is 0, it must be a clear zero. Instead it was " + length + ".");
    }
    return setTimeout(fn, length);
  };

}).call(this);

//# sourceMappingURL=call-delayed.js.map
